==> spip_4.0.4.orig.tar.xz: plugins-dist/medias/lang/medias_oc_ni.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=oc_ni
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_ajouter_document' => 'Ajustar un document',
	'bouton_ajouter_image' => 'Ajustar un imatge',

	// D
	'double_clic_inserer_doc' => 'Besclicatz per inserir aquela escorcha dins lo tèxt.',

	// E
	'entree_dimensions' => 'Dimensions:',
	'entree_titre_document' => 'Titre dau document:',
	'entree_titre_image' => 'Titre de l’imatge:',

	// I
	'image_tourner_180' => 'Rotacion 180°',
	'image_tourner_droite' => 'Rotacion 90° à drecha',
	'image_tourner_gauche' => 'Rotacion 90° à senèca',
	'info_document' => 'Document ',
	'info_document_indisponible' => 'Aqueu document es pas disponible',
	'info_documents' => 'Documents',
	'info_inclusion_directe' => 'Inclusion dirècta :',
	'info_inclusion_vignette' => 'Inclusion de la vinheta:',
	'info_installer_tous_documents' => 'Installar toi lu documents',
	'info_logo_max_taille' => 'Lu lògos devon obligatòriament faire mens de @maxi@ (aquèu fichier fa @actuel@).',
	'info_portfolio' => 'Poartfolio',
	'info_referencer_doc_distant' => 'Referençar un document sus l’internet :',
	'info_telecharger' => 'Telecargar despí lo voastre ordinator :',

	// T
	'texte_documents_joints' => 'Podètz autorisar l’ajust de documents (fichiers burotics, imatges,
 multimèdia, eca.) ai articles e/ò ai rubricas. Aquelu fichiers
 poadon pi èstre referençats dins l’article, ò aparéisser à despart.', # MODIF
	'texte_documents_joints_2' => 'Aqueu reglatge empedisse pas l’insercion d’imatges directament dins lu articles.', # MODIF
	'titre_documents_joints' => 'Documents jonchs',
	'tout_dossier_upload' => 'Tot lo dorsier @upload@',

	// U
	'upload_fichier_zip' => 'Fichier ZIP',
	'upload_fichier_zip_texte' => 'Lo fichier que prepausatz d’installar es un fichier ZIP.',
	'upload_fichier_zip_texte2' => 'Aquèu fichier pòu èstre :',
	'upload_limit' => 'Aquèu fichier es tròp gròs per lo servidor; la talha maximala autorisada en <i>upload</i> es de @max@.',
	'upload_zip_decompacter' => 'descomprimit e cada element que conten installat sus lo sit. Alora lu fichiers que seràn installats sus lo sit son :',
	'upload_zip_telquel' => 'installat tau quau, coma archiu comprimit Zip;'
);

==> spip_4.4.6+dfsg.orig.tar.xz: plugins-dist/medias/lang/medias_oc_ni.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=oc_ni
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_ajouter_document' => 'Ajustar un document',
	'bouton_ajouter_image' => 'Ajustar un imatge',

	// D
	'double_clic_inserer_doc' => 'Besclicatz per inserir aquela escorcha dins lo tèxt.',

	// E
	'entree_dimensions' => 'Dimensions:',
	'entree_titre_document' => 'Titre dau document:',
	'entree_titre_image' => 'Titre de l’imatge:',

	// I
	'image_tourner_180' => 'Rotacion 180°',
	'image_tourner_droite' => 'Rotacion 90° à drecha',
	'image_tourner_gauche' => 'Rotacion 90° à senèca',
	'info_document' => 'Document ',
	'info_document_indisponible' => 'Aqueu document es pas disponible',
	'info_documents' => 'Documents',
	'info_inclusion_directe' => 'Inclusion dirècta :',
	'info_inclusion_vignette' => 'Inclusion de la vinheta:',
	'info_installer_tous_documents' => 'Installar toi lu documents',
	'info_logo_max_taille' => 'Lu lògos devon obligatòriament faire mens de @maxi@ (aquèu fichier fa @actuel@).',
	'info_portfolio' => 'Poartfolio',
	'info_referencer_doc_distant' => 'Referençar un document sus l’internet :',
	'info_telecharger' => 'Telecargar despí lo voastre ordinator :',

	// T
	'texte_documents_joints' => 'Podètz autorisar l’ajust de documents (fichiers burotics, imatges,
 multimèdia, eca.) ai articles e/ò ai rubricas. Aquelu fichiers
 poadon pi èstre referençats dins l’article, ò aparéisser à despart.', # MODIF
	'texte_documents_joints_2' => 'Aqueu reglatge empedisse pas l’insercion d’imatges directament dins lu articles.', # MODIF
	'titre_documents_joints' => 'Documents jonchs',
	'tout_dossier_upload' => 'Tot lo dorsier @upload@',

	// U
	'upload_fichier_zip' => 'Fichier ZIP',
	'upload_fichier_zip_texte' => 'Lo fichier que prepausatz d’installar es un fichier ZIP.',
	'upload_fichier_zip_texte2' => 'Aquèu fichier pòu èstre :',
	'upload_limit' => 'Aquèu fichier es tròp gròs per lo servidor; la talha maximala autorisada en <i>upload</i> es de @max@.',
	'upload_zip_decompacter' => 'descomprimit e cada element que conten installat sus lo sit. Alora lu fichiers que seràn installats sus lo sit son :',
	'upload_zip_telquel' => 'installat tau quau, coma archiu comprimit Zip;',
];
